"use strict";
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Sorts the keys of the given object.
 * @returns A new object instance with sorted keys
 */
function sortObjectByKeys(obj) {
    return Object.keys(obj).sort().reduce((result, key) => (result[key] = obj[key]) && result, {});
}
function addPackageToPackageJson(host, pkg, version, dependencies = 'dependencies') {
    return savePackageJson(host, (json) => {
        if (!json[dependencies]) {
            json[dependencies] = {};
        }
        if (!json[dependencies][pkg]) {
            json[dependencies][pkg] = version;
            json[dependencies] = sortObjectByKeys(json[dependencies]);
        }
        return json;
    });
}
exports.addPackageToPackageJson = addPackageToPackageJson;
/** Gets the version of the specified package by looking at the package.json in the given tree. */
function getPackageVersionFromPackageJson(tree, name) {
    if (!tree.exists('package.json')) {
        return null;
    }
    const packageJson = JSON.parse(tree.read('package.json').toString('utf8'));
    if (packageJson.dependencies && packageJson.dependencies[name]) {
        return packageJson.dependencies[name];
    }
    return null;
}
exports.getPackageVersionFromPackageJson = getPackageVersionFromPackageJson;
function savePackageJson(host, callback) {
    return saveJson(host, 'package.json', callback);
}
exports.savePackageJson = savePackageJson;
function saveJson(host, path, callback) {
    return saveFile(host, path, (src) => {
        const json = JSON.parse(src);
        return JSON.stringify(callback(json));
    });
}
exports.saveJson = saveJson;
function saveFile(host, path, callback) {
    if (host.exists(path)) {
        const src = host.read(path).toString('utf-8');
        const dest = callback(src);
        host.overwrite(path, dest);
    }
    else {
        host.create(path, callback(''));
    }
    return host;
}
exports.saveFile = saveFile;
//# sourceMappingURL=package-config.js.map